<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 *
 *
 * @package ext_bibsonomy_csl
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 * @author Sebastian Böttger
 *
 */
class Tx_ExtBibsonomyCsl_Controller_CitationStylesheetController extends Tx_ExtBibsonomyCsl_Controller_AbstractActionController {

    const EXAMPLE_CITE = '{"DOI":"","ISBN":"","URL":"","abstract":"","author":[{"family":"Einstein","given":"Albert"},{"family":"Grossmann","given":"Marcel"}],"citation-label":"Einstein1913","collection-title":"","container-title":"","editor":[],"event-place":"","id":"76b6a8740eec04a155f846436c8fb2a9marco.giovanell","issued":{"date-parts":[["1913"]],"literal":"1913"},"note":"CPAE 4, 13","page":"225-244, 245-261","publisher":"","title":"Entwurf einer verallgemeinerten Relativitätstheorie und eine Theorie\n\tder Gravitation. I. Physikalischer Teil von A. Einstein II. Mathematischer\n\tTeil von M. Grossmann","volume":"62"}';

    /**
     * citationStylesheetRepository
     *
     * @var Tx_ExtBibsonomyCsl_Domain_Repository_CitationStylesheetRepository
     */
    protected $citationStylesheetRepository;

    /**
     * injectCitationStylesheetRepository
     *
     * @param Tx_ExtBibsonomyCsl_Domain_Repository_CitationStylesheetRepository $citationStylesheetRepository
     * @return void
     */
    public function injectCitationStylesheetRepository(Tx_ExtBibsonomyCsl_Domain_Repository_CitationStylesheetRepository $citationStylesheetRepository) {
        $this->citationStylesheetRepository = $citationStylesheetRepository;
    }

    /**
     * @return void
     */
    public function initializeAction() {

        $this->citationStylesheetRepository = t3lib_div::makeInstance('Tx_ExtBibsonomyCsl_Domain_Repository_CitationStylesheetRepository');
    }

    /**
     *
     * @return void
     */
    public function listAction() {

        $result = $this->citationStylesheetRepository->findAll();
        $this->view->assign('styles', $result);
        $this->view->assign('example', self::EXAMPLE_CITE);
    }

    /**
     *
     * @param Tx_ExtBibsonomyCsl_Domain_Model_CitationStylesheet $stylesheet 
     */
    public function newAction(
    Tx_ExtBibsonomyCsl_Domain_Model_CitationStylesheet $stylesheet = null) {

        $this->view->assign('stylesheet', $stylesheet);
    }

    /**
     *
     * @param Tx_ExtBibsonomyCsl_Domain_Model_CitationStylesheet $stylesheet 
     */
    public function createAction(
    Tx_ExtBibsonomyCsl_Domain_Model_CitationStylesheet $stylesheet) {

        $this->citationStylesheetRepository->add($stylesheet);
        $this->flashMessages->add('Stylesheet added.');
        $this->redirect('list');
    }

    /**
     * A template method for displaying custom error flash messages, or to
     * display no flash message at all on errors. Override this to customize
     * the flash message in your action controller.
     *
     * @return string|boolean The flash message or FALSE if no flash message should be set
     * @api
     */
    protected function getErrorFlashMessage() {
        return 'An error occurred while trying to call ' . get_class($this) . '->' . $this->actionMethodName . '()';
    }

}

?>