<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Sebastian Boettger <boettger@cs.uni-kassel.de>, Knowledge and Data Engineering Group (University of Kassel)
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ************************************************************** */

require_once t3lib_extMgm::extPath("ext_bibsonomy_csl") . 'Classes/Lib/Helper.php';

/**
 * Action Controller for frontend plugin 'Bibsonomy Publication List'.
 * Contains an action to assign a list of publications and a compare method 
 * for sorting the list of publications
 *
 * @package ext_bibsonomy_csl
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 * @author Sebastian Böttger
 *
 */
class Tx_ExtBibsonomyCsl_Controller_PublicationController extends Tx_ExtBibsonomyCsl_Controller_AbstractActionController {

    /**
     * publicationRepository
     *
     * @var Tx_ExtBibsonomyCsl_Domain_Repository_PublicationRepository
     */
    protected $publicationRepository;

    /**
     * citationStylesheetRepository
     *
     * @var Tx_ExtBibsonomyCsl_Domain_Repository_CitationStylesheetRepository
     */
    protected $citationStylesheetRepository;

    /**
     * injectPublicationRepository
     *
     * @param Tx_ExtBibsonomyCsl_Domain_Repository_PublicationRepository $publicationRepository
     * @return void
     */
    public function injectPublicationRepository(
    Tx_ExtBibsonomyCsl_Domain_Repository_PublicationRepository $publicationRepository) {

        $this->publicationRepository = $publicationRepository;
    }

    /**
     * @return void 
     */
    public function initializeAction() {
        if ($this->publicationRepository == null) {
            $this->publicationRepository = & t3lib_div::makeInstance('Tx_ExtBibsonomyCsl_Domain_Repository_PublicationRepository');
        }
    }

    /**
     * Assigns fetched publications to view.
     *
     * @return void
     */
    public function listAction() {
        global $GLOBALS;
        $publications = $this->publicationRepository->fetchPublications($this->settings);
        usort($publications, "self::cmp");

        if (trim($this->settings["bib_ownstylesheet"]) == "") {

            $this->citationStylesheetRepository = & t3lib_div::makeInstance('Tx_ExtBibsonomyCsl_Domain_Repository_CitationStylesheetRepository');
            $stylesheetId = $this->settings['bib_stylesheet'];
            $citationStylesheet = $this->citationStylesheetRepository->findById($stylesheetId);
            
        } else {

            $citationStylesheet = Tx_ExtBibsonomyCsl_Helper::createStylesheetObject($this->settings["bib_ownstylesheet"]);
        }

        $this->view->assign('grouping', $this->settings['bib_grouping']);
        $this->view->assign('displayAnchors', $this->settings['bib_display_anchors']);

        $this->view->assign('publications', $publications);
        $this->view->assign('citationStylesheet', $citationStylesheet);
        $this->view->assign('host', $this->settings["bib_server"]);
        $GLOBALS['TSFE']->additionalHeaderData['ext_bibsonomy_csl'] = '<style type="text/css">' . "\n" . $this->settings['bib_css_attribute_for_list_item'] . "\n" . '</style>';
    }

    /**
     * compare function for php sorting function
     *
     * @param Tx_ExtBibsonomyCsl_Domain_Model_Publication $a
     * @param Tx_ExtBibsonomyCsl_Domain_Model_Publication $b
     * @return int 
     */
    public function cmp(
    Tx_ExtBibsonomyCsl_Domain_Model_Publication $a, Tx_ExtBibsonomyCsl_Domain_Model_Publication $b) {

        if ($this->settings['bib_sorting'] == "") {
            return 0;
        }
        if ($this->settings['bib_sorting'] == "year") {
            return ($this->settings['bib_sorting_order'] == "asc") ? $a->cmpYear($b) : (-1) * $a->cmpYear($b);
        } else {
            //TODO: Implement for comparing entrytypes
        }
    }

}

?>